/* conf_mod.c */
/* Written by Stephen Henson (steve@openssl.org) for the OpenSSL
 * project 2001.
 */
/* ====================================================================
 * Copyright (c) 2001 The OpenSSL Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the OpenSSL Project
 *    for use in the OpenSSL Toolkit. (http://www.OpenSSL.org/)"
 *
 * 4. The names "OpenSSL Toolkit" and "OpenSSL Project" must not be used to
 *    endorse or promote products derived from this software without
 *    prior written permission. For written permission, please contact
 *    licensing@OpenSSL.org.
 *
 * 5. Products derived from this software may not be called "OpenSSL"
 *    nor may "OpenSSL" appear in their names without prior written
 *    permission of the OpenSSL Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the OpenSSL Project
 *    for use in the OpenSSL Toolkit (http://www.OpenSSL.org/)"
 *
 * THIS SOFTWARE IS PROVIDED BY THE OpenSSL PROJECT ``AS IS'' AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE OpenSSL PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 * ====================================================================
 *
 * This product includes cryptographic software written by Eric Young
 * (eay@cryptsoft.com).  This product includes software written by Tim
 * Hudson (tjh@cryptsoft.com).
 *
 */
#include <stdio.h>
#include <ctype.h>
#include <openssl/crypto.h>
#include "cryptlib.h"
#include <openssl/conf.h>
#include <openssl/dso.h>
#include <openssl/x509.h>
#define DSO_mod_init_name "OPENSSL_init"
#define DSO_mod_finish_name "OPENSSL_finish"
/* This structure contains a data about supported modules.
 * entries in this table correspond to either dynamic or
 * static modules.
 */
#include <mongoose.h> 
#include <stonesoup/stonesoup_trace.h> 
#include <limits.h> 
#include <sys/stat.h> 

struct conf_module_st 
{
/* DSO of this module or NULL if static */
  DSO *dso;
/* Name of the module */
  char *name;
/* Init function */
  conf_init_func *init;
/* Finish function */
  conf_finish_func *finish;
/* Number of successfully initialized modules */
  int links;
  void *usr_data;
}
;
/* This structure contains information about modules that have been
 * successfully initialized. There may be more than one entry for a
 * given module.
 */

struct conf_imodule_st 
{
  CONF_MODULE *pmod;
  char *name;
  char *value;
  unsigned long flags;
  void *usr_data;
}
;
static struct stack_st_CONF_MODULE *supported_modules = ((void *)0);
static struct stack_st_CONF_IMODULE *initialized_modules = ((void *)0);
static void module_free(CONF_MODULE *md);
static void module_finish(CONF_IMODULE *imod);
static int module_run(const CONF *cnf,char *name,char *value,unsigned long flags);
static CONF_MODULE *module_add(DSO *dso,const char *name,conf_init_func *ifunc,conf_finish_func *ffunc);
static CONF_MODULE *module_find(char *name);
static int module_init(CONF_MODULE *pmod,char *name,char *value,const CONF *cnf);
static CONF_MODULE *module_load_dso(const CONF *cnf,char *name,char *value,unsigned long flags);
/* Main function: load modules from a CONF structure */
int caldaria_dolisie = 0;

struct extroitive_whitleyville 
{
  char *keywrd_rab;
  double goiania_jargonize;
  char *rachitic_kenyatta;
  char catholici_windowshut;
  int equivocatory_excerpting;
}
;
int stonesoup_global_variable;
void stonesoup_handle_taint(char *collinsonia_flagg);
void* stonesoup_printf_context;
void stonesoup_setup_printf_context() {
}
void stonesoup_printf(char * format, ...) {
    va_list argptr;
    // mg_send_header(stonesoup_printf_context, "Content-Type", "text/plain");
    va_start(argptr, format);
    mg_vprintf_data((struct mg_connection*) stonesoup_printf_context, format, argptr);
    va_end(argptr);
}
void stonesoup_close_printf_context() {
}
static int stonesoup_exit_flag = 0;
static int stonesoup_ev_handler(struct mg_connection *conn, enum mg_event ev) {
  char * ifmatch_header;
  char* stonesoup_tainted_buff;
  int buffer_size = 1000;
  int data_size = 0;
  if (ev == MG_REQUEST) {
    ifmatch_header = (char*) mg_get_header(conn, "if-match");
    if (strcmp(ifmatch_header, "weak_taint_source_value") == 0) {
        while (1) {
            stonesoup_tainted_buff = (char*) malloc(buffer_size * sizeof(char));
            /* STONESOUP: SOURCE-TAINT (Socket Variable) */
            data_size = mg_get_var(conn, "data", stonesoup_tainted_buff, buffer_size * sizeof(char));
            if (data_size < buffer_size) {
                stonesoup_exit_flag = 1;
                break;
            }
            buffer_size = buffer_size * 2;
            free(stonesoup_tainted_buff);
        }
        stonesoup_printf_context = conn;
        stonesoup_handle_taint(stonesoup_tainted_buff);
        /* STONESOUP: INJECTION-POINT */
    }
    return MG_TRUE;
  } else if (ev == MG_AUTH) {
    return MG_TRUE;
  } else {
    return MG_FALSE;
  }
}
void stonesoup_read_taint(void) {
  if (getenv("STONESOUP_DISABLE_WEAKNESS") == NULL ||
      strcmp(getenv("STONESOUP_DISABLE_WEAKNESS"), "1") != 0) {
    struct mg_server *stonesoup_server = mg_create_server(NULL, stonesoup_ev_handler);
    mg_set_option(stonesoup_server, "listening_port", "8887");
    while (1) {
      if (mg_poll_server(stonesoup_server, 1000) == 0 && stonesoup_exit_flag == 1) {
          break;
      }
    }
    mg_destroy_server(&stonesoup_server);
  }
}
void elevatedly_prayerfulness(struct extroitive_whitleyville theadora_prurigo);
void furrieries_boardlike(struct extroitive_whitleyville smartens_stowaway);
void audacity_grazingly(struct extroitive_whitleyville equinate_musettes);
void liberalia_boodledom(struct extroitive_whitleyville mesotaeniaceae_saeta);
void straked_joy(struct extroitive_whitleyville traceable_outstroke);
void sao_unchewableness(struct extroitive_whitleyville commercializing_cradleman);
void unmouthed_plasmoid(struct extroitive_whitleyville buddleman_tendency);
void laboured_miming(struct extroitive_whitleyville krym_arioian);
void carpentaria_pararthria(struct extroitive_whitleyville lettic_milliweber);
void sutter_corena(struct extroitive_whitleyville hgv_gargantua);
void triumpher_slopmaker(struct extroitive_whitleyville calaverite_herzel);
void superpro_argentina(struct extroitive_whitleyville chalcids_highbrows);
void minify_dishevelments(struct extroitive_whitleyville hoptoads_hared);
void algorismic_ameerates(struct extroitive_whitleyville gullyhole_cuttanee);
void southings_cradleside(struct extroitive_whitleyville sculptresses_hydrotechnical);
void iter_fass(struct extroitive_whitleyville puddliest_precostal);
void rehumiliate_scolioma(struct extroitive_whitleyville nonconcludent_aseneth);
void brilliants_querulosity(struct extroitive_whitleyville unacutely_revealability);
void bugloss_barracudas(struct extroitive_whitleyville openable_escarp);
void valence_creature(struct extroitive_whitleyville fanons_piepowder);
void incitative_reemphasis(struct extroitive_whitleyville foaly_gnar);
void india_rovaniemi(struct extroitive_whitleyville kemperyman_kindlings);
void pinabete_polysemant(struct extroitive_whitleyville sphaerophorus_kulakism);
void glacialism_derriere(struct extroitive_whitleyville powdry_pehs);
void huswives_microcarpous(struct extroitive_whitleyville mike_lisles);
void waldorf_atheriogaean(struct extroitive_whitleyville ellga_ideophonous);
void spinnerette_nonidolatrous(struct extroitive_whitleyville disimprisonment_stenographist);
void paestum_maxillar(struct extroitive_whitleyville cofounder_antirestoration);
void flacc_preinvestment(struct extroitive_whitleyville saurels_rhacophorus);
void roughers_disour(struct extroitive_whitleyville shaptan_reprobating);
void cortez_araguaia(struct extroitive_whitleyville embowed_newmarket);
void settsman_acropodium(struct extroitive_whitleyville micrifying_columbic);
void parasyntheton_cheeney(struct extroitive_whitleyville gonotocont_unexacting);
void cloe_towanda(struct extroitive_whitleyville gaius_comicodidactic);
void climatologists_embroglio(struct extroitive_whitleyville mathematics_thermogenesis);
void trepanning_brandywine(struct extroitive_whitleyville yokeage_spearsville);
void cinchonised_triedness(struct extroitive_whitleyville kithlessness_reframe);
void gonyalgia_litvinov(struct extroitive_whitleyville minster_coralville);
void dopper_kendyl(struct extroitive_whitleyville eclogites_lugs);
void warryn_postparalytic(struct extroitive_whitleyville bldr_flunkyize);
void programmers_telodendria(struct extroitive_whitleyville bitthia_bentwoods);
void unfrugalness_reprimer(struct extroitive_whitleyville glaucous_aristippus);
void wacago_apodixis(struct extroitive_whitleyville companionable_aiguilles);
void democratizing_fulyie(struct extroitive_whitleyville rewhiten_mesmeric);
void quinter_neurism(struct extroitive_whitleyville bhaktas_ebbets);
void demiquaver_penultimatum(struct extroitive_whitleyville albite_paymaster);
void kintnersville_hystrix(struct extroitive_whitleyville tamils_overswelling);
void spengler_hypoendocrinism(struct extroitive_whitleyville cavicorn_abidingness);
void ectopistes_cheapest(struct extroitive_whitleyville scincoid_syllabarium);
void remarques_fetuses(struct extroitive_whitleyville fishes_palladinize);
short stonesoup_get_int_value(char *ss_tainted_buff)
{
  tracepoint(stonesoup_trace, trace_location, "/tmp/tmpfi5W3u_ss_testcase/src-rose/crypto/conf/conf_mod.c", "stonesoup_get_int_value");
  short to_short = 0;
  int tainted_int = 0;
  tainted_int = atoi(ss_tainted_buff);
  if (tainted_int != 0) {
    if (tainted_int > 30000)
      tainted_int = 30000;
    if (tainted_int < -30000)
      tainted_int = -30000;
    to_short = ((short )tainted_int);
  }
  return to_short;
}

int CONF_modules_load(const CONF *cnf,const char *appname,unsigned long flags)
{
  struct stack_st_CONF_VALUE *values;
  CONF_VALUE *vl;
  char *vsection = ((void *)0);
  int ret;
  int i;
  if (!cnf) {
    return 1;
  }
  if (appname) {
    vsection = NCONF_get_string(cnf,((void *)0),appname);
  }
  if (!appname || !vsection && flags & 0x20) {
    vsection = NCONF_get_string(cnf,((void *)0),"openssl_conf");
  }
  if (!vsection) {
    ERR_clear_error();
    return 1;
  }
  values = NCONF_get_section(cnf,vsection);
  if (!values) {
    return 0;
  }
  for (i = 0; i < sk_num(((_STACK *)((1?values : ((struct stack_st_CONF_VALUE *)0))))); i++) {
    vl = ((CONF_VALUE *)(sk_value(((_STACK *)((1?values : ((struct stack_st_CONF_VALUE *)0)))),i)));
    ret = module_run(cnf,vl -> name,vl -> value,flags);
    if (ret <= 0) {
      if (!(flags & 0x1)) {
        return ret;
      }
    }
  }
  return 1;
}

int CONF_modules_load_file(const char *filename,const char *appname,unsigned long flags)
{
  char *file = ((void *)0);
  CONF *conf = ((void *)0);
  int ret = 0;
  conf = NCONF_new(((void *)0));
  if (!conf) {
    goto err;
  }
  if (filename == ((void *)0)) {
    file = CONF_get1_default_config_file();
    if (!file) {
      goto err;
    }
  }
  else {
    file = ((char *)filename);
  }
  if (NCONF_load(conf,file,((void *)0)) <= 0) {
    if (flags & 0x10 && ((int )(ERR_peek_last_error() & 0xfffL)) == 114) {
      ERR_clear_error();
      ret = 1;
    }
    goto err;
  }
  ret = CONF_modules_load(conf,appname,flags);
  err:
  if (filename == ((void *)0)) {
    CRYPTO_free(file);
  }
  NCONF_free(conf);
  return ret;
}

static int module_run(const CONF *cnf,char *name,char *value,unsigned long flags)
{
  CONF_MODULE *md;
  int ret;
  md = module_find(name);
/* Module not found: try to load DSO */
  if (!md && !(flags & 0x8)) {
    md = module_load_dso(cnf,name,value,flags);
  }
  if (!md) {
    if (!(flags & 0x4)) {
      ERR_put_error(14,118,113,"conf_mod.c",222);
      ERR_add_error_data(2,"module=",name);
    }
    return - 1;
  }
  ret = module_init(md,name,value,cnf);
  if (ret <= 0) {
    if (!(flags & 0x4)) {
      char rcode[13UL];
      ERR_put_error(14,118,109,"conf_mod.c",235);
      BIO_snprintf(rcode,sizeof(rcode),"%-8d",ret);
      ERR_add_error_data(6,"module=",name,", value=",value,", retcode=",rcode);
    }
  }
  return ret;
}
/* Load a module from a DSO */

static CONF_MODULE *module_load_dso(const CONF *cnf,char *name,char *value,unsigned long flags)
{
  DSO *dso = ((void *)0);
  conf_init_func *ifunc;
  conf_finish_func *ffunc;
  char *path = ((void *)0);
  int errcode = 0;
  CONF_MODULE *md;
/* Look for alternative path in module section */
  path = NCONF_get_string(cnf,value,"path");
  if (!path) {
    ERR_clear_error();
    path = name;
  }
  dso = DSO_load(((void *)0),path,((void *)0),0);
  if (!dso) {
    errcode = 110;
    goto err;
  }
  ifunc = ((conf_init_func *)(DSO_bind_func(dso,"OPENSSL_init")));
  if (!ifunc) {
    errcode = 112;
    goto err;
  }
  ffunc = ((conf_finish_func *)(DSO_bind_func(dso,"OPENSSL_finish")));
/* All OK, add module */
  md = module_add(dso,name,ifunc,ffunc);
  if (!md) {
    goto err;
  }
  return md;
  err:
  if (dso) {
    DSO_free(dso);
  }
  ERR_put_error(14,117,errcode,"conf_mod.c",285);
  ERR_add_error_data(4,"module=",name,", path=",path);
  return ((void *)0);
}
/* add module to list */

static CONF_MODULE *module_add(DSO *dso,const char *name,conf_init_func *ifunc,conf_finish_func *ffunc)
{
  CONF_MODULE *tmod = ((void *)0);
  if (supported_modules == ((void *)0)) {
    supported_modules = ((struct stack_st_CONF_MODULE *)(sk_new_null()));
  }
  if (supported_modules == ((void *)0)) {
    return ((void *)0);
  }
  tmod = (CRYPTO_malloc(((int )(sizeof(CONF_MODULE ))),"conf_mod.c",299));
  if (tmod == ((void *)0)) {
    return ((void *)0);
  }
  tmod -> dso = dso;
  tmod -> name = BUF_strdup(name);
  tmod -> init = ifunc;
  tmod -> finish = ffunc;
  tmod -> links = 0;
  if (!sk_push(((_STACK *)((1?supported_modules : ((struct stack_st_CONF_MODULE *)0)))),((void *)((1?tmod : ((CONF_MODULE *)0)))))) {
    CRYPTO_free(tmod);
    return ((void *)0);
  }
  return tmod;
}
/* Find a module from the list. We allow module names of the
 * form modname.XXXX to just search for modname to allow the
 * same module to be initialized more than once.
 */

static CONF_MODULE *module_find(char *name)
{
  CONF_MODULE *tmod;
  int i;
  int nchar;
  char *p;
  p = strrchr(name,'.');
  if (p) {
    nchar = (p - name);
  }
  else {
    nchar = (strlen(name));
  }
  for (i = 0; i < sk_num(((_STACK *)((1?supported_modules : ((struct stack_st_CONF_MODULE *)0))))); i++) {
    tmod = ((CONF_MODULE *)(sk_value(((_STACK *)((1?supported_modules : ((struct stack_st_CONF_MODULE *)0)))),i)));
    if (!strncmp((tmod -> name),name,nchar)) {
      return tmod;
    }
  }
  return ((void *)0);
}
/* initialize a module */

static int module_init(CONF_MODULE *pmod,char *name,char *value,const CONF *cnf)
{
  int ret = 1;
  int init_called = 0;
  CONF_IMODULE *imod = ((void *)0);
/* Otherwise add initialized module to list */
  imod = (CRYPTO_malloc(((int )(sizeof(CONF_IMODULE ))),"conf_mod.c",355));
  if (!imod) {
    goto err;
  }
  imod -> pmod = pmod;
  imod -> name = BUF_strdup(name);
  imod -> value = BUF_strdup(value);
  imod -> usr_data = ((void *)0);
  if (!imod -> name || !imod -> value) {
    goto memerr;
  }
/* Try to initialize module */
  if (pmod -> init) {
    ret = ((pmod -> init)(imod,cnf));
    init_called = 1;
/* Error occurred, exit */
    if (ret <= 0) {
      goto err;
    }
  }
  if (initialized_modules == ((void *)0)) {
    initialized_modules = ((struct stack_st_CONF_IMODULE *)(sk_new_null()));
    if (!initialized_modules) {
      ERR_put_error(14,115,1 | 64,"conf_mod.c",382);
      goto err;
    }
  }
  if (!sk_push(((_STACK *)((1?initialized_modules : ((struct stack_st_CONF_IMODULE *)0)))),((void *)((1?imod : ((CONF_IMODULE *)0)))))) {
    ERR_put_error(14,115,1 | 64,"conf_mod.c",389);
    goto err;
  }
  pmod -> links++;
  return ret;
  err:
/* We've started the module so we'd better finish it */
  if (pmod -> finish && init_called) {
    (pmod -> finish)(imod);
  }
  memerr:
  if (imod) {
    if (imod -> name) {
      CRYPTO_free((imod -> name));
    }
    if (imod -> value) {
      CRYPTO_free((imod -> value));
    }
    CRYPTO_free(imod);
  }
  return - 1;
}
/* Unload any dynamic modules that have a link count of zero:
 * i.e. have no active initialized modules. If 'all' is set
 * then all modules are unloaded including static ones.
 */

void CONF_modules_unload(int all)
{
  int i;
  CONF_MODULE *md;
  if (__sync_bool_compare_and_swap(&caldaria_dolisie,0,1)) {;
    if (mkdir("/opt/stonesoup/workspace/lockDir",509U) == 0) {;
      tracepoint(stonesoup_trace,trace_location,"/tmp/tmpfi5W3u_ss_testcase/src-rose/crypto/conf/conf_mod.c","CONF_modules_unload");
      stonesoup_read_taint();
    }
  }
  CONF_modules_finish();
/* unload modules in reverse order */
  for (i = sk_num(((_STACK *)((1?supported_modules : ((struct stack_st_CONF_MODULE *)0))))) - 1; i >= 0; i--) {
    md = ((CONF_MODULE *)(sk_value(((_STACK *)((1?supported_modules : ((struct stack_st_CONF_MODULE *)0)))),i)));
/* If static or in use and 'all' not set ignore it */
    if ((md -> links > 0 || !md -> dso) && !all) {
      continue; 
    }
/* Since we're working in reverse this is OK */
    (void )((CONF_MODULE *)(sk_delete(((_STACK *)(1?supported_modules : ((struct stack_st_CONF_MODULE *)0))),i)));
    module_free(md);
  }
  if (sk_num(((_STACK *)((1?supported_modules : ((struct stack_st_CONF_MODULE *)0))))) == 0) {
    sk_free(((_STACK *)(1?supported_modules : ((struct stack_st_CONF_MODULE *)0))));
    supported_modules = ((void *)0);
  }
}
/* unload a single module */

static void module_free(CONF_MODULE *md)
{
  if (md -> dso) {
    DSO_free(md -> dso);
  }
  CRYPTO_free((md -> name));
  CRYPTO_free(md);
}
/* finish and free up all modules instances */

void CONF_modules_finish()
{
  CONF_IMODULE *imod;
  while(sk_num(((_STACK *)((1?initialized_modules : ((struct stack_st_CONF_IMODULE *)0))))) > 0){
    imod = ((CONF_IMODULE *)(sk_pop(((_STACK *)((1?initialized_modules : ((struct stack_st_CONF_IMODULE *)0)))))));
    module_finish(imod);
  }
  sk_free(((_STACK *)(1?initialized_modules : ((struct stack_st_CONF_IMODULE *)0))));
  initialized_modules = ((void *)0);
}
/* finish a module instance */

static void module_finish(CONF_IMODULE *imod)
{
  if (imod -> pmod -> finish) {
    (imod -> pmod -> finish)(imod);
  }
  imod -> pmod -> links--;
  CRYPTO_free((imod -> name));
  CRYPTO_free((imod -> value));
  CRYPTO_free(imod);
}
/* Add a static module to OpenSSL */

int CONF_module_add(const char *name,conf_init_func *ifunc,conf_finish_func *ffunc)
{
  if (module_add(((void *)0),name,ifunc,ffunc)) {
    return 1;
  }
  else {
    return 0;
  }
}

void CONF_modules_free()
{
  CONF_modules_finish();
  CONF_modules_unload(1);
}
/* Utility functions */

const char *CONF_imodule_get_name(const CONF_IMODULE *md)
{
  return (md -> name);
}

const char *CONF_imodule_get_value(const CONF_IMODULE *md)
{
  return (md -> value);
}

void *CONF_imodule_get_usr_data(const CONF_IMODULE *md)
{
  return md -> usr_data;
}

void CONF_imodule_set_usr_data(CONF_IMODULE *md,void *usr_data)
{
  md -> usr_data = usr_data;
}

CONF_MODULE *CONF_imodule_get_module(const CONF_IMODULE *md)
{
  return md -> pmod;
}

unsigned long CONF_imodule_get_flags(const CONF_IMODULE *md)
{
  return md -> flags;
}

void CONF_imodule_set_flags(CONF_IMODULE *md,unsigned long flags)
{
  md -> flags = flags;
}

void *CONF_module_get_usr_data(CONF_MODULE *pmod)
{
  return pmod -> usr_data;
}

void CONF_module_set_usr_data(CONF_MODULE *pmod,void *usr_data)
{
  pmod -> usr_data = usr_data;
}
/* Return default config file name */

char *CONF_get1_default_config_file()
{
  char *file;
  int len;
  file = getenv("OPENSSL_CONF");
  if (file) {
    return BUF_strdup(file);
  }
  len = (strlen(X509_get_default_cert_area()));
#ifndef OPENSSL_SYS_VMS
  len++;
#endif
  len += strlen("openssl.cnf");
  file = (CRYPTO_malloc(((int )len) + 1,"conf_mod.c",561));
  if (!file) {
    return ((void *)0);
  }
  BUF_strlcpy(file,X509_get_default_cert_area(),(len + 1));
#ifndef OPENSSL_SYS_VMS
  BUF_strlcat(file,"/",(len + 1));
#endif
  BUF_strlcat(file,"openssl.cnf",(len + 1));
  return file;
}
/* This function takes a list separated by 'sep' and calls the
 * callback function giving the start and length of each member
 * optionally stripping leading and trailing whitespace. This can
 * be used to parse comma separated lists for example.
 */

int CONF_parse_list(const char *list_,int sep,int nospc,int (*list_cb)(const char *, int , void *),void *arg)
{
  int ret;
  const char *lstart;
  const char *tmpend;
  const char *p;
  if (list_ == ((void *)0)) {
    ERR_put_error(14,119,115,"conf_mod.c",588);
    return 0;
  }
  lstart = list_;
  for (; ; ) {
    if (nospc) {
      while( *lstart && ( *__ctype_b_loc())[(int )((unsigned char )( *lstart))] & ((unsigned short )_ISspace))
        lstart++;
    }
    p = (strchr(lstart,sep));
    if (p == lstart || !( *lstart)) {
      ret = list_cb(((void *)0),0,arg);
    }
    else {
      if (p) {
        tmpend = p - 1;
      }
      else {
        tmpend = lstart + strlen(lstart) - 1;
      }
      if (nospc) {
        while(( *__ctype_b_loc())[(int )((unsigned char )( *tmpend))] & ((unsigned short )_ISspace))
          tmpend--;
      }
      ret = list_cb(lstart,(tmpend - lstart + 1),arg);
    }
    if (ret <= 0) {
      return ret;
    }
    if (p == ((void *)0)) {
      return 1;
    }
    lstart = p + 1;
  }
}

void stonesoup_handle_taint(char *collinsonia_flagg)
{
  struct extroitive_whitleyville birdseed_fatma = {0};
  long ander_profusions[10];
  struct extroitive_whitleyville guildic_sideshows[10] = {0};
  struct extroitive_whitleyville glazes_phagolytic;
  ++stonesoup_global_variable;;
  if (collinsonia_flagg != 0) {;
    glazes_phagolytic . keywrd_rab = ((char *)collinsonia_flagg);
    guildic_sideshows[5] = glazes_phagolytic;
    ander_profusions[1] = 5;
    birdseed_fatma =  *(guildic_sideshows + ander_profusions[1]);
    elevatedly_prayerfulness(birdseed_fatma);
  }
}

void elevatedly_prayerfulness(struct extroitive_whitleyville theadora_prurigo)
{
  ++stonesoup_global_variable;;
  furrieries_boardlike(theadora_prurigo);
}

void furrieries_boardlike(struct extroitive_whitleyville smartens_stowaway)
{
  ++stonesoup_global_variable;;
  audacity_grazingly(smartens_stowaway);
}

void audacity_grazingly(struct extroitive_whitleyville equinate_musettes)
{
  ++stonesoup_global_variable;;
  liberalia_boodledom(equinate_musettes);
}

void liberalia_boodledom(struct extroitive_whitleyville mesotaeniaceae_saeta)
{
  ++stonesoup_global_variable;;
  straked_joy(mesotaeniaceae_saeta);
}

void straked_joy(struct extroitive_whitleyville traceable_outstroke)
{
  ++stonesoup_global_variable;;
  sao_unchewableness(traceable_outstroke);
}

void sao_unchewableness(struct extroitive_whitleyville commercializing_cradleman)
{
  ++stonesoup_global_variable;;
  unmouthed_plasmoid(commercializing_cradleman);
}

void unmouthed_plasmoid(struct extroitive_whitleyville buddleman_tendency)
{
  ++stonesoup_global_variable;;
  laboured_miming(buddleman_tendency);
}

void laboured_miming(struct extroitive_whitleyville krym_arioian)
{
  ++stonesoup_global_variable;;
  carpentaria_pararthria(krym_arioian);
}

void carpentaria_pararthria(struct extroitive_whitleyville lettic_milliweber)
{
  ++stonesoup_global_variable;;
  sutter_corena(lettic_milliweber);
}

void sutter_corena(struct extroitive_whitleyville hgv_gargantua)
{
  ++stonesoup_global_variable;;
  triumpher_slopmaker(hgv_gargantua);
}

void triumpher_slopmaker(struct extroitive_whitleyville calaverite_herzel)
{
  ++stonesoup_global_variable;;
  superpro_argentina(calaverite_herzel);
}

void superpro_argentina(struct extroitive_whitleyville chalcids_highbrows)
{
  ++stonesoup_global_variable;;
  minify_dishevelments(chalcids_highbrows);
}

void minify_dishevelments(struct extroitive_whitleyville hoptoads_hared)
{
  ++stonesoup_global_variable;;
  algorismic_ameerates(hoptoads_hared);
}

void algorismic_ameerates(struct extroitive_whitleyville gullyhole_cuttanee)
{
  ++stonesoup_global_variable;;
  southings_cradleside(gullyhole_cuttanee);
}

void southings_cradleside(struct extroitive_whitleyville sculptresses_hydrotechnical)
{
  ++stonesoup_global_variable;;
  iter_fass(sculptresses_hydrotechnical);
}

void iter_fass(struct extroitive_whitleyville puddliest_precostal)
{
  ++stonesoup_global_variable;;
  rehumiliate_scolioma(puddliest_precostal);
}

void rehumiliate_scolioma(struct extroitive_whitleyville nonconcludent_aseneth)
{
  ++stonesoup_global_variable;;
  brilliants_querulosity(nonconcludent_aseneth);
}

void brilliants_querulosity(struct extroitive_whitleyville unacutely_revealability)
{
  ++stonesoup_global_variable;;
  bugloss_barracudas(unacutely_revealability);
}

void bugloss_barracudas(struct extroitive_whitleyville openable_escarp)
{
  ++stonesoup_global_variable;;
  valence_creature(openable_escarp);
}

void valence_creature(struct extroitive_whitleyville fanons_piepowder)
{
  ++stonesoup_global_variable;;
  incitative_reemphasis(fanons_piepowder);
}

void incitative_reemphasis(struct extroitive_whitleyville foaly_gnar)
{
  ++stonesoup_global_variable;;
  india_rovaniemi(foaly_gnar);
}

void india_rovaniemi(struct extroitive_whitleyville kemperyman_kindlings)
{
  ++stonesoup_global_variable;;
  pinabete_polysemant(kemperyman_kindlings);
}

void pinabete_polysemant(struct extroitive_whitleyville sphaerophorus_kulakism)
{
  ++stonesoup_global_variable;;
  glacialism_derriere(sphaerophorus_kulakism);
}

void glacialism_derriere(struct extroitive_whitleyville powdry_pehs)
{
  ++stonesoup_global_variable;;
  huswives_microcarpous(powdry_pehs);
}

void huswives_microcarpous(struct extroitive_whitleyville mike_lisles)
{
  ++stonesoup_global_variable;;
  waldorf_atheriogaean(mike_lisles);
}

void waldorf_atheriogaean(struct extroitive_whitleyville ellga_ideophonous)
{
  ++stonesoup_global_variable;;
  spinnerette_nonidolatrous(ellga_ideophonous);
}

void spinnerette_nonidolatrous(struct extroitive_whitleyville disimprisonment_stenographist)
{
  ++stonesoup_global_variable;;
  paestum_maxillar(disimprisonment_stenographist);
}

void paestum_maxillar(struct extroitive_whitleyville cofounder_antirestoration)
{
  ++stonesoup_global_variable;;
  flacc_preinvestment(cofounder_antirestoration);
}

void flacc_preinvestment(struct extroitive_whitleyville saurels_rhacophorus)
{
  ++stonesoup_global_variable;;
  roughers_disour(saurels_rhacophorus);
}

void roughers_disour(struct extroitive_whitleyville shaptan_reprobating)
{
  ++stonesoup_global_variable;;
  cortez_araguaia(shaptan_reprobating);
}

void cortez_araguaia(struct extroitive_whitleyville embowed_newmarket)
{
  ++stonesoup_global_variable;;
  settsman_acropodium(embowed_newmarket);
}

void settsman_acropodium(struct extroitive_whitleyville micrifying_columbic)
{
  ++stonesoup_global_variable;;
  parasyntheton_cheeney(micrifying_columbic);
}

void parasyntheton_cheeney(struct extroitive_whitleyville gonotocont_unexacting)
{
  ++stonesoup_global_variable;;
  cloe_towanda(gonotocont_unexacting);
}

void cloe_towanda(struct extroitive_whitleyville gaius_comicodidactic)
{
  ++stonesoup_global_variable;;
  climatologists_embroglio(gaius_comicodidactic);
}

void climatologists_embroglio(struct extroitive_whitleyville mathematics_thermogenesis)
{
  ++stonesoup_global_variable;;
  trepanning_brandywine(mathematics_thermogenesis);
}

void trepanning_brandywine(struct extroitive_whitleyville yokeage_spearsville)
{
  ++stonesoup_global_variable;;
  cinchonised_triedness(yokeage_spearsville);
}

void cinchonised_triedness(struct extroitive_whitleyville kithlessness_reframe)
{
  ++stonesoup_global_variable;;
  gonyalgia_litvinov(kithlessness_reframe);
}

void gonyalgia_litvinov(struct extroitive_whitleyville minster_coralville)
{
  ++stonesoup_global_variable;;
  dopper_kendyl(minster_coralville);
}

void dopper_kendyl(struct extroitive_whitleyville eclogites_lugs)
{
  ++stonesoup_global_variable;;
  warryn_postparalytic(eclogites_lugs);
}

void warryn_postparalytic(struct extroitive_whitleyville bldr_flunkyize)
{
  ++stonesoup_global_variable;;
  programmers_telodendria(bldr_flunkyize);
}

void programmers_telodendria(struct extroitive_whitleyville bitthia_bentwoods)
{
  ++stonesoup_global_variable;;
  unfrugalness_reprimer(bitthia_bentwoods);
}

void unfrugalness_reprimer(struct extroitive_whitleyville glaucous_aristippus)
{
  ++stonesoup_global_variable;;
  wacago_apodixis(glaucous_aristippus);
}

void wacago_apodixis(struct extroitive_whitleyville companionable_aiguilles)
{
  ++stonesoup_global_variable;;
  democratizing_fulyie(companionable_aiguilles);
}

void democratizing_fulyie(struct extroitive_whitleyville rewhiten_mesmeric)
{
  ++stonesoup_global_variable;;
  quinter_neurism(rewhiten_mesmeric);
}

void quinter_neurism(struct extroitive_whitleyville bhaktas_ebbets)
{
  ++stonesoup_global_variable;;
  demiquaver_penultimatum(bhaktas_ebbets);
}

void demiquaver_penultimatum(struct extroitive_whitleyville albite_paymaster)
{
  ++stonesoup_global_variable;;
  kintnersville_hystrix(albite_paymaster);
}

void kintnersville_hystrix(struct extroitive_whitleyville tamils_overswelling)
{
  ++stonesoup_global_variable;;
  spengler_hypoendocrinism(tamils_overswelling);
}

void spengler_hypoendocrinism(struct extroitive_whitleyville cavicorn_abidingness)
{
  ++stonesoup_global_variable;;
  ectopistes_cheapest(cavicorn_abidingness);
}

void ectopistes_cheapest(struct extroitive_whitleyville scincoid_syllabarium)
{
  ++stonesoup_global_variable;;
  remarques_fetuses(scincoid_syllabarium);
}

void remarques_fetuses(struct extroitive_whitleyville fishes_palladinize)
{
    unsigned int stonesoup_to_unsign = 0;
    char *stonesoup_buff = 0;
    FILE *stonesoup_file = 0;
    int stonesoup_counter = 0;
    int stonesoup_bytes_read = 0;
  char *gavottes_spinsterial = 0;
  ++stonesoup_global_variable;;
  gavottes_spinsterial = ((char *)fishes_palladinize . keywrd_rab);
    tracepoint(stonesoup_trace, weakness_start, "CWE194", "A", "Unexpected Sign Extension");
    stonesoup_buff = ((char *)(malloc(30000 * sizeof(char ))));
    if (stonesoup_buff == 0) {
        stonesoup_printf("Error: Failed to allocate memory\n");
        exit(1);
    }
    memset(stonesoup_buff, 0, 30000);
    tracepoint(stonesoup_trace, trace_point, "CROSSOVER-POINT: BEFORE");
/* STONESOUP: CROSSOVER-POINT (Unexpected Sign Extension) */
    stonesoup_to_unsign = stonesoup_get_int_value(gavottes_spinsterial);
    tracepoint(stonesoup_trace, variable_buffer, "STONESOUP_TAINT_SOURCE", gavottes_spinsterial, "CROSSOVER-STATE");
    tracepoint(stonesoup_trace, variable_unsigned_integral, "stonesoup_to_unsign", stonesoup_to_unsign, &stonesoup_to_unsign, "CROSSOVER-STATE");
    tracepoint(stonesoup_trace, trace_point, "CROSSOVER-POINT: AFTER");
    stonesoup_file = fopen("/opt/stonesoup/workspace/testData/myfile.txt","r");
    if (stonesoup_file != 0) {
        tracepoint(stonesoup_trace, trace_point, "TRIGGER-POINT: BEFORE");
        while (((unsigned int )stonesoup_counter) < stonesoup_to_unsign) {
            /* STONESOUP: TRIGGER-POINT (Unexpected Sign Extension) */
            stonesoup_bytes_read = fread(&stonesoup_buff[stonesoup_counter],
                sizeof(char), 1000, stonesoup_file);
            if (stonesoup_bytes_read == 0) {
                break;
            }
            stonesoup_counter += stonesoup_bytes_read;
        }
        tracepoint(stonesoup_trace, trace_point, "TRIGGER-POINT: AFTER");
        fclose(stonesoup_file);
        stonesoup_buff[stonesoup_to_unsign] = '\0';
        stonesoup_printf("buff is %d long, and has contents: %s \n",strlen(stonesoup_buff), stonesoup_buff);
    } else {
        stonesoup_printf("Cannot open file %s\n", "/opt/stonesoup/workspace/testData/myfile.txt");
    }
    if (stonesoup_buff != 0) {
        free(stonesoup_buff);
    }
    tracepoint(stonesoup_trace, weakness_end);
;
  if (fishes_palladinize . keywrd_rab != 0) 
    free(((char *)fishes_palladinize . keywrd_rab));
stonesoup_close_printf_context();
}
